@@ -73,6 +73,54 @@ class AccessV3Test(utils.TestCase):
         self.assertTrue(auth_ref.will_expire_soon(stale_duration=301))
         self.assertFalse(auth_ref.will_expire_soon())
 
+    def test_building_system_scoped_assessinfo(self):
+        token = fixture.V3Token()
+        token.set_system_scope()
+
+        s = token.add_service(type='identity')
+        s.add_standard_endpoints(public='http://url')
+
+        token_id = uuid.uuid4().hex
+
+        auth_ref = access.create(body=token, auth_token=token_id)
+
+        self.assertTrue(auth_ref)
+        self.assertIn('methods', auth_ref._data['token'])
+        self.assertIn('catalog', auth_ref._data['token'])
+        self.assertTrue(auth_ref.has_service_catalog())
+        self.assertTrue(auth_ref._data['token']['catalog'])
+
+        self.assertEqual(token_id, auth_ref.auth_token)
+        self.assertEqual(token.user_name, auth_ref.username)
+        self.assertEqual(token.user_id, auth_ref.user_id)
+
+        self.assertEqual(token.role_ids, auth_ref.role_ids)
+        self.assertEqual(token.role_names, auth_ref.role_names)
+
+        self.assertEqual(token.domain_name, auth_ref.domain_name)
+        self.assertEqual(token.domain_id, auth_ref.domain_id)
+
+        self.assertEqual(token.user_domain_id, auth_ref.user_domain_id)
+        self.assertEqual(token.user_domain_name, auth_ref.user_domain_name)
+
+        self.assertIsNone(auth_ref.project_name)
+        self.assertIsNone(auth_ref.project_id)
+
+        self.assertIsNone(auth_ref.project_domain_id)
+        self.assertIsNone(auth_ref.project_domain_name)
+
+        self.assertIsNone(auth_ref.domain_name)
+        self.assertIsNone(auth_ref.domain_id)
+
+        self.assertEqual(token.system, auth_ref.system)
+
+        self.assertTrue(auth_ref.system_scoped)
+        self.assertFalse(auth_ref.domain_scoped)
+        self.assertFalse(auth_ref.project_scoped)
+
+        self.assertEqual(token.audit_id, auth_ref.audit_id)
+        self.assertEqual(token.audit_chain_id, auth_ref.audit_chain_id)
+
     def test_building_domain_scoped_accessinfo(self):
         token = fixture.V3Token()
         token.set_domain_scope()
